==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Tux/Resources/translations/Tux_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Επιλογή</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation type="unfinished">Zoom</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Περιστροφή</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation type="unfinished">Pan</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation type="unfinished">Tilt</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation type="unfinished">Navigation style</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation type="unfinished">Page Up or Page Down key.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation type="unfinished">Rotation focus</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation type="unfinished">Middle mouse button or key H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation type="unfinished">Middle mouse button.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation type="unfinished">Navigation style not recognized.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Στύλ Τροχιάς</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation type="unfinished">Compact</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation type="unfinished">Tooltip</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Στρεψόδισκος</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Οδηγόσφαιρα</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Απροσδιόριστο</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Tux/Resources/translations/Tux_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>NavigationIndicator</name>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="62"/>
      <source>Select</source>
      <translation>Επιλέξτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="63"/>
      <source>Zoom</source>
      <translation>Εστίαση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="64"/>
      <source>Rotate</source>
      <translation>Περιστρέψτε</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="65"/>
      <source>Pan</source>
      <translation>Μεταφορική Κίνηση Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="66"/>
      <source>Tilt</source>
      <translation>Ρύθμιση Κλίσης Κάμερας</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="67"/>
      <source>Navigation style</source>
      <translation>Τύπος Πλοήγησης</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="68"/>
      <source>Page Up or Page Down key.</source>
      <translation>Το πλήκτρο Μετακίνησης της Σελίδας προς τα Πάνω ή προς τα Κάτω.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="69"/>
      <source>Rotation focus</source>
      <translation>Άξονας περιστροφής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="70"/>
      <source>Middle mouse button or key H.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού ή πλήκτρο H.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="71"/>
      <source>Middle mouse button.</source>
      <translation>Μεσαίο πλήκτρο του ποντικιού.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="74"/>
      <source>Navigation style not recognized.</source>
      <translation>Ο τύπος πλοήγησης δεν αναγνωρίζεται.</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="291"/>
      <source>Settings</source>
      <translation type="unfinished">Settings</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="292"/>
      <source>Orbit style</source>
      <translation>Τύπος μορφοποίησης τροχιάς</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="293"/>
      <source>Compact</source>
      <translation>Συμπαγής</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="294"/>
      <source>Tooltip</source>
      <translation>Επεξήγηση εργαλείου</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="295"/>
      <source>Turntable</source>
      <translation>Περιστρεφόμενη βάση</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="296"/>
      <source>Trackball</source>
      <translation>Ιχνόσφαιρα</translation>
    </message>
    <message>
      <location filename="../../NavigationIndicatorGui.py" line="297"/>
      <source>Undefined</source>
      <translation>Απροσδιόριστο</translation>
    </message>
  </context>
</TS>
